==> dif-database-repository-2.3.11-7-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/TemplateRepositoryServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.ITemplateRepositoryService;
import pt.digitalis.dif.dem.managers.impl.model.dao.ITemplateRepositoryDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.impl.TemplateRepositoryDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.TemplateRepository;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class TemplateRepositoryServiceImpl implements ITemplateRepositoryService {

	/**
	 * Obtains a new TemplateRepository DAO
	 *
	 * @return A new ITemplateRepositoryDAO
	 */
    public ITemplateRepositoryDAO getTemplateRepositoryDAO() {
    	return new TemplateRepositoryDAOImpl();
    }

    /**
     * Obtains a new DataSet for the TemplateRepository entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<TemplateRepository> getTemplateRepositoryDataSet() {
        return new HibernateDataSet<TemplateRepository>(TemplateRepository.class, new TemplateRepositoryDAOImpl(),
                TemplateRepository.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == TemplateRepository.class)
            return getTemplateRepositoryDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(TemplateRepository.class.getSimpleName()))
            return getTemplateRepositoryDataSet();

        return null;
    }
}

==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/TemplateRepositoryServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.ITemplateRepositoryService;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.ITemplateRepositoryDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.impl.TemplateRepositoryDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.TemplateRepository;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class TemplateRepositoryServiceImpl implements ITemplateRepositoryService {

	/**
	 * Obtains a new TemplateRepository DAO
	 *
	 * @return A new ITemplateRepositoryDAO
	 */
    public ITemplateRepositoryDAO getTemplateRepositoryDAO() {
    	return new TemplateRepositoryDAOImpl();
    }

    /**
     * Obtains a new DataSet for the TemplateRepository entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<TemplateRepository> getTemplateRepositoryDataSet() {
        return new HibernateDataSet<TemplateRepository>(TemplateRepository.class, new TemplateRepositoryDAOImpl(),
                TemplateRepository.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == TemplateRepository.class)
            return getTemplateRepositoryDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(TemplateRepository.class.getSimpleName()))
            return getTemplateRepositoryDataSet();

        return null;
    }
}
